/*
 * Copyright 2012 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.api.internal.tasks.compile;

import org.gradle.process.ExecSpec;
import org.gradle.internal.process.ArgCollector;

public class ExecSpecBackedArgCollector implements ArgCollector {
    private final ExecSpec action;

    public ExecSpecBackedArgCollector(ExecSpec action) {
        this.action = action;
    }

    @Override
    public ArgCollector args(Object... args) {
        action.args(args);
        return this;
    }

    @Override
    public ArgCollector args(Iterable<?> args) {
        action.args(args);
        return this;
    }
}
